import { useState, useEffect } from "react";
import { Button } from "@/components/ui/button";
import {
  ArrowRight,
  Sparkles,
  TrendingUp,
  ShoppingBag,
  Clock,
  Star,
  ChevronRight,
} from "lucide-react";
import SEOImage from "@/components/SEOImage";
import { HeroSkeleton } from "@/components/SkeletonLoaders";
import { deferAction } from "@/utils/performanceUtils";

const HeroSection = () => {
  const [isLoaded, setIsLoaded] = useState(false);

  useEffect(() => {
    // Track when hero content has loaded
    const markAsLoaded = () => setIsLoaded(true);
    
    // Set as loaded immediately if it's a repeat visit (likely cached)
    if (window.performance) {
      const navEntry = performance.getEntriesByType('navigation')[0] as PerformanceNavigationTiming;
      if (navEntry && (navEntry.type === 'back_forward' || navEntry.type === 'reload')) {
        markAsLoaded();
      } else {
        // Otherwise show skeleton briefly for perceived performance
        deferAction(markAsLoaded, 150);
      }
    } else {
      deferAction(markAsLoaded, 150);
    }
  }, []);
  // Show skeleton while loading
  if (!isLoaded) {
    return <HeroSkeleton />;
  }

  return (
    <section className="min-h-screen bg-gradient-to-b from-white to-orange-50/20 pt-32 md:pt-34 overflow-hidden relative">
      {/* Background Elements */}
      <div className="absolute inset-0 overflow-hidden pointer-events-none">
        {/* Grid pattern */}
        <div
          className="absolute inset-0 opacity-10"
          style={{
            backgroundImage: `
              linear-gradient(to right, #64748b 0.5px, transparent 0.5px),
              linear-gradient(to bottom, #64748b 0.5px, transparent 0.5px)
            `,
            backgroundSize: "40px 40px",
            backgroundPosition: "center center",
            maskImage:
              "linear-gradient(to bottom, transparent 0%, black 10%, black 90%, transparent 100%)",
            WebkitMaskImage:
              "linear-gradient(to bottom, transparent 0%, black 10%, black 90%, transparent 100%)",
            zIndex: 0,
          }}
        />

        {/* Gradient overlay */}
        <div className="absolute inset-0 bg-gradient-to-b from-white/30 via-transparent to-orange-50/20"></div>

        {/* Animated blobs */}
        <div className="absolute inset-0 overflow-hidden">
          <div className="absolute top-10 right-10 w-72 h-72 bg-orange-100 rounded-full mix-blend-multiply filter blur-3xl opacity-40 animate-blob"></div>
          <div className="absolute -top-20 -left-20 w-72 h-72 bg-amber-100 rounded-full mix-blend-multiply filter blur-3xl opacity-40 animate-blob animation-delay-2000"></div>
          <div className="absolute bottom-20 left-10 w-64 h-64 bg-yellow-100 rounded-full mix-blend-multiply filter blur-3xl opacity-30 animate-blob animation-delay-4000"></div>
          <div className="absolute top-1/3 left-1/4 w-6 h-6 bg-orange-400/30 rounded-full blur-sm"></div>
          <div className="absolute top-2/3 right-1/3 w-4 h-4 bg-amber-400/40 rounded-full blur-sm"></div>
          <div className="absolute bottom-1/4 right-1/4 w-5 h-5 bg-yellow-400/30 rounded-full blur-sm"></div>
          <div className="absolute top-1/2 left-10 w-3 h-3 bg-orange-500/30 rounded-full blur-sm"></div>
        </div>
      </div>

      <div className="container mx-auto px-4 md:px-6 pt-8 md:pt-12 pb-12 md:pb-20 relative z-10">
        <div className="grid lg:grid-cols-2 gap-8 md:gap-16 items-center">
          {/* Left Content */}
          <div className="space-y-8 md:space-y-10">
            <div className="inline-flex items-center bg-gradient-to-r from-orange-100/90 to-amber-100/90 backdrop-blur-sm px-5 py-2.5 rounded-full text-orange-600 font-medium text-sm border border-orange-200/50 shadow-md animate-fade-in transition-all duration-300 hover:shadow-lg hover:scale-105">
              <Sparkles className="w-4 h-4 mr-2 text-orange-500 animate-pulse" />

              <span>Transforming Pet Stores Digitally</span>
            </div>

            <div
              className="space-y-6 animate-fade-in"
              style={{ animationDelay: "0.2s" }}
            >
              <h1 className="text-4xl sm:text-5xl md:text-6xl lg:text-7xl font-extrabold leading-tight text-gray-900">
                From Local Store to
                <div className="relative inline-block mt-2 w-full">
                  <span className="relative z-10 block bg-gradient-to-r from-orange-500 via-orange-600 to-amber-500 bg-clip-text text-transparent">
                    Digital Empire
                  </span>
                </div>
              </h1>

              <p className="text-lg md:text-xl text-gray-600 leading-relaxed max-w-2xl font-medium">
                Join <span className="text-orange-600 font-semibold">400+</span>{" "}
                traditional pet stores already winning against quick commerce
                giants. Transform your neighborhood store into a hyperlocal
                delivery powerhouse in just{" "}
                <span className="text-orange-600 font-semibold">24 hours</span>.
              </p>
            </div>

            <div
              className="flex flex-col sm:flex-row gap-4 animate-fade-in"
              style={{ animationDelay: "0.4s" }}
            >
              <Button
                variant="default"
                size="lg"
                className="group bg-gradient-to-r from-orange-500 to-amber-500 hover:from-orange-600 hover:to-amber-600 text-white shadow-lg hover:shadow-xl transition-all duration-300 border-0 py-6 px-8"
              >
                <span className="text-base font-semibold">
                  Start Your Transformation
                </span>
                <ArrowRight className="h-5 w-5 ml-2 group-hover:translate-x-1 transition-transform" />
              </Button>
            </div>

            {/* Stats */}
            <div
              className="grid grid-cols-3 gap-6 md:gap-10 pt-8 border-t border-gray-200/70 animate-fade-in"
              style={{ animationDelay: "0.6s" }}
            >
              <div className="group relative bg-white/60 backdrop-blur-sm p-4 rounded-xl shadow-sm hover:shadow-md transition-all duration-300 hover:scale-105 border border-gray-100/50">
                <div className="absolute -top-2 -right-2 w-4 h-4 bg-orange-100 rounded-full opacity-70"></div>
                <div className="text-2xl md:text-4xl font-bold bg-gradient-to-r from-orange-500 to-orange-600 bg-clip-text text-transparent">
                  400+
                </div>
                <div className="text-sm text-gray-600 font-medium mt-1 flex items-center">
                  <ShoppingBag className="w-3 h-3 mr-1 text-orange-400" />

                  <span>Stores Transformed</span>
                </div>
              </div>
              <div className="group relative bg-white/60 backdrop-blur-sm p-4 rounded-xl shadow-sm hover:shadow-md transition-all duration-300 hover:scale-105 border border-gray-100/50">
                <div className="absolute -top-2 -right-2 w-4 h-4 bg-amber-100 rounded-full opacity-70"></div>
                <div className="text-2xl md:text-4xl font-bold bg-gradient-to-r from-amber-500 to-orange-500 bg-clip-text text-transparent">
                  500%
                </div>
                <div className="text-sm text-gray-600 font-medium mt-1 flex items-center">
                  <TrendingUp className="w-3 h-3 mr-1 text-amber-400" />

                  <span>Average Growth</span>
                </div>
              </div>
              <div className="group relative bg-white/60 backdrop-blur-sm p-4 rounded-xl shadow-sm hover:shadow-md transition-all duration-300 hover:scale-105 border border-gray-100/50">
                <div className="absolute -top-2 -right-2 w-4 h-4 bg-yellow-100 rounded-full opacity-70"></div>
                <div className="text-2xl md:text-4xl font-bold bg-gradient-to-r from-yellow-500 to-amber-500 bg-clip-text text-transparent">
                  24hrs
                </div>
                <div className="text-sm text-gray-600 font-medium mt-1 flex items-center">
                  <Clock className="w-3 h-3 mr-1 text-yellow-500" />

                  <span>Setup Time</span>
                </div>
              </div>
            </div>
          </div>

          {/* Right Visual with App Screenshot */}
          <div
            className="relative animate-fade-in mt-8 lg:mt-0"
            style={{ animationDelay: "0.6s" }}
          >
            {/* Phone frame */}
            <div className="relative z-10 flex justify-center">
              <div className="relative">
                {/* App Screenshot - Optimized */}
                <div className="relative overflow-hidden rounded-3xl shadow-2xl transition-all duration-500 hover:shadow-orange-500/10 hover:-translate-y-2">
                  <SEOImage
                    src="/lovable-uploads/ed4680ef-e7d0-4e7d-b7de-88452ae90aed.png"
                    alt="TailsMart Mobile App"
                    width={320}
                    height={650}
                    priority={true}
                    loading="eager"
                    className="w-64 sm:w-72 md:w-80 h-auto"
                  />
                </div>

                {/* Floating UI Elements in zig-zag positioning */}
                <div className="absolute inset-0 pointer-events-none">
                  {/* Revenue Card - Top Right */}
                  <div
                    className="absolute -top-12 -right-10 rotate-3 transition-all duration-500 hover:scale-105 hover:rotate-0 z-20 group"
                    style={{
                      filter: "drop-shadow(0 8px 16px rgba(0, 0, 0, 0.06))",
                    }}
                  >
                    <div className="bg-white/95 backdrop-blur-sm rounded-2xl shadow-lg p-4 w-44 border border-gray-100/60">
                      <div className="flex justify-between items-center mb-2">
                        <span className="text-sm font-medium text-gray-700">
                          Revenue
                        </span>
                        <span className="text-xs bg-green-100 text-green-700 px-2 py-0.5 rounded-full font-medium">
                          +24.5%
                        </span>
                      </div>
                      <div className="h-12 w-full relative">
                        <svg viewBox="0 0 120 40" className="w-full h-full">
                          <path
                            d="M0,30 C20,25 40,35 60,25 S100,20 120,30"
                            fill="none"
                            stroke="#f97316"
                            strokeWidth="2"
                            strokeLinecap="round"
                          />
                        </svg>
                      </div>
                      <div className="text-xs text-gray-500 font-medium mt-1 text-right">
                        Last 7 days
                      </div>
                    </div>
                  </div>

                  {/* On-time Delivery - Middle Left */}
                  <div
                    className="absolute top-1/4 -left-20 -translate-y-1/3 -rotate-2 transition-all duration-500 hover:scale-105 hover:rotate-0 z-20 group"
                    style={{
                      filter: "drop-shadow(0 8px 16px rgba(0, 0, 0, 0.06))",
                    }}
                  >
                    <div className="bg-white/95 backdrop-blur-sm rounded-2xl shadow-lg p-4 w-32 border border-gray-100/60">
                      <div className="flex flex-col items-center">
                        <div className="relative w-16 h-16 mb-1">
                          <svg className="w-full h-full" viewBox="0 0 36 36">
                            <circle
                              cx="18"
                              cy="18"
                              r="15.5"
                              fill="none"
                              stroke="#f3f4f6"
                              strokeWidth="2.5"
                            ></circle>
                            <circle
                              cx="18"
                              cy="18"
                              r="15.5"
                              fill="none"
                              stroke="#f97316"
                              strokeWidth="2.5"
                              strokeDasharray="88, 100"
                              strokeDashoffset="25"
                            />

                            <text
                              x="18"
                              y="17"
                              textAnchor="middle"
                              fontSize="7"
                              fontWeight="bold"
                              fill="#374151"
                            >
                              88%
                            </text>
                            <text
                              x="18"
                              y="24"
                              textAnchor="middle"
                              fontSize="3.5"
                              fill="#6b7280"
                            >
                              Target: 90%
                            </text>
                          </svg>
                        </div>
                        <span className="text-xs font-medium text-center text-gray-700">
                          On-time Delivery
                        </span>
                      </div>
                    </div>
                  </div>

                  {/* Rating Card - Middle Right */}
                  <div
                    className="absolute top-2/3 -right-16 -translate-y-1/2 rotate-2 transition-all duration-500 hover:scale-105 hover:rotate-0 z-20 group"
                    style={{
                      filter: "drop-shadow(0 8px 16px rgba(0, 0, 0, 0.06))",
                    }}
                  >
                    <div className="bg-white/95 backdrop-blur-sm rounded-2xl shadow-lg p-4 w-36 border border-gray-100/60">
                      <div className="flex justify-between items-center mb-2">
                        <div>
                          <span className="text-xs font-medium text-gray-700 block">
                            App Rating
                          </span>
                        </div>
                        <span className="text-xs bg-orange-100 text-orange-700 px-1.5 py-0.5 rounded-full font-medium">
                          Top 5%
                        </span>
                      </div>
                      <div className="flex items-center">
                        <div className="flex">
                          {[...Array(5)].map((_, i) => (
                            <Star
                              key={i}
                              className={`w-4 h-4 ${i < 4 ? "text-yellow-400" : "text-gray-200"}`}
                              fill="currentColor"
                            />
                          ))}
                        </div>
                        <span className="ml-2 text-lg font-bold">4.8</span>
                      </div>
                      <div className="text-xs text-gray-500 mt-1">
                        Based on 200+ reviews
                      </div>
                    </div>
                  </div>

                  {/* Today's Orders - Bottom Left */}
                  <div
                    className="absolute -bottom-14 -left-12 -rotate-3 transition-all duration-500 hover:scale-105 hover:rotate-0 z-20 group"
                    style={{
                      filter: "drop-shadow(0 8px 16px rgba(0, 0, 0, 0.06))",
                    }}
                  >
                    <div className="bg-white/95 backdrop-blur-sm rounded-2xl shadow-lg p-4 w-44 border border-gray-100/60">
                      <div className="flex items-center mb-2">
                        <div className="w-7 h-7 rounded-md bg-orange-100 flex items-center justify-center mr-2">
                          <ShoppingBag className="w-3.5 h-3.5 text-orange-500" />
                        </div>
                        <div>
                          <span className="text-sm font-medium text-gray-800 block">
                            Today's Orders
                          </span>
                          <div className="flex items-center">
                            <div className="w-1.5 h-1.5 bg-green-500 rounded-full mr-1"></div>
                            <span className="text-xs text-green-600">+12%</span>
                          </div>
                        </div>
                      </div>
                      <div className="text-center">
                        <span className="text-4xl font-bold text-gray-900 block">
                          47
                        </span>
                      </div>
                      <div className="w-full bg-gray-100 rounded-full h-2 mt-2">
                        <div
                          className="bg-orange-500 h-2 rounded-full"
                          style={{ width: "78%" }}
                        ></div>
                      </div>
                      <div className="flex justify-between text-xs text-gray-500 mt-1">
                        <span>47/60 orders</span>
                        <span>78%</span>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>

            {/* Background decorations */}
            <div className="absolute -top-10 right-10 w-32 h-32 bg-orange-300/20 rounded-full blur-3xl"></div>
            <div className="absolute -bottom-10 left-10 w-32 h-32 bg-amber-300/20 rounded-full blur-3xl"></div>
            <div className="absolute top-1/2 right-1/4 w-24 h-24 bg-yellow-300/20 rounded-full blur-3xl"></div>
          </div>
        </div>
      </div>

      {/* Animation keyframes */}
      <style
        dangerouslySetInnerHTML={{
          __html: `
        @keyframes blob {
          0% { transform: translate(0px, 0px) scale(1); }
          33% { transform: translate(30px, -50px) scale(1.1); }
          66% { transform: translate(-20px, 20px) scale(0.9); }
          100% { transform: translate(0px, 0px) scale(1); }
        }
        .animate-blob {
          animation: blob 7s infinite;
        }
        .animation-delay-2000 {
          animation-delay: 2s;
        }
        .animation-delay-4000 {
          animation-delay: 4s;
        }
      `,
        }}
      />
    </section>
  );
};

export default HeroSection;
